### About allhub

allhub is a collection of utilities to work with Github API. I am no way interested to support git API.
If somebody integrates allhub with pygit2, they are more than welcome to do so.
